#[non_exhaustive]pub struct EncryptedContent {
pub info: EncryptedFileInfo,
pub hashes: EncryptedFileHashes,
}Available on crate features
events and unstable-msc3551 only.Expand description
The encryption info of a file sent to a room with end-to-end encryption enabled.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.info: EncryptedFileInfoInformation about the encryption of the file.
hashes: EncryptedFileHashesA map from an algorithm name to a hash of the ciphertext.
Clients should support the SHA-256 hash, which uses the key sha256.
Implementations
Sourceimpl EncryptedContent
impl EncryptedContent
Sourcepub fn new(
info: EncryptedFileInfo,
hashes: EncryptedFileHashes,
) -> EncryptedContent
pub fn new( info: EncryptedFileInfo, hashes: EncryptedFileHashes, ) -> EncryptedContent
Construct a new EncryptedContent with the given encryption info and hashes.